Struct rustc_typeck::middle::ty::UpvarBorrowUnstable
[-] [+]
[src]
pub struct UpvarBorrow {
pub kind: BorrowKind,
pub region: Region,
}Fields
kind | The kind of borrow: by-ref upvars have access to shared immutable borrows, which are not part of the normal language syntax. |
region | Region of the resulting reference. |